@@ -4,12 +4,12 @@ First version of the un-marshalling process of javaobj.
 
 :authors: Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.1
+:version: 0.4.3
 :status: Alpha
 
 ..
 
-    Copyright 2020 Thomas Calmant
+    Copyright 2021 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -24,20 +24,20 @@ First version of the un-marshalling process of javaobj.
     limitations under the License.
 """
 
-from . import beans, core, transformers
-from .core import (
+from . import beans, core, transformers  # noqa: F401
+from .core import (  # noqa: F401
     load,
     loads,
     dumps,
     JavaObjectMarshaller,
     JavaObjectUnmarshaller,
 )
-from .transformers import DefaultObjectTransformer
+from .transformers import DefaultObjectTransformer  # noqa: F401
 
 # ------------------------------------------------------------------------------
 
 # Module version
-__version_info__ = (0, 4, 1)
+__version_info__ = (0, 4, 3)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
