@@ -13,12 +13,12 @@ http://download.oracle.com/javase/6/docs/platform/serialization/spec/protocol.ht
 
 :authors: Volodymyr Buell, Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.1
+:version: 0.4.3
 :status: Alpha
 
 ..
 
-    Copyright 2020 Thomas Calmant
+    Copyright 2021 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -65,18 +65,14 @@ from ..utils import (
     hexdump,
 )
 
-# Numpy array support
-try:
-    import numpy
-except ImportError:
-    numpy = None
+numpy = None  # Imported only when really used
 
 # ------------------------------------------------------------------------------
 
 __all__ = ("JavaObjectUnmarshaller",)
 
 # Module version
-__version_info__ = (0, 4, 1)
+__version_info__ = (0, 4, 3)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -113,6 +109,16 @@ class JavaObjectUnmarshaller:
         """
         self.use_numpy_arrays = use_numpy_arrays
 
+        # Numpy array support
+        if self.use_numpy_arrays:
+            try:
+                global numpy
+                import numpy as np
+
+                numpy = np
+            except ImportError:
+                pass
+
         # Check stream
         if stream is None:
             raise IOError("No input stream given")
@@ -221,7 +227,8 @@ class JavaObjectUnmarshaller:
 
         if expect and opid not in expect:
             raise IOError(
-                "Unexpected opcode 0x{0:X} -- {1} (at offset 0x{2:X})".format(
+                "Unexpected opcode 0x{0:X} -- {1} "
+                "(at offset 0x{2:X})".format(
                     opid, StreamCodeDebug.op_id(opid), position
                 )
             )
@@ -230,9 +237,8 @@ class JavaObjectUnmarshaller:
             handler = self.opmap[opid]
         except KeyError:
             raise RuntimeError(
-                "Unknown OpCode in the stream: 0x{0:X} (at offset 0x{1:X})".format(
-                    opid, position
-                )
+                "Unknown OpCode in the stream: 0x{0:X} "
+                "(at offset 0x{1:X})".format(opid, position)
             )
         else:
             return opid, handler(ident=ident)
@@ -329,7 +335,7 @@ class JavaObjectUnmarshaller:
                     expect=(TerminalCode.TC_STRING, TerminalCode.TC_REFERENCE),
                 )
 
-                if type(field_type) is not JavaString:
+                if type(field_type) is not JavaString:  # pylint:disable=C0123
                     raise AssertionError(
                         "Field type must be a JavaString, "
                         "not {0}".format(type(field_type))
@@ -345,7 +351,7 @@ class JavaObjectUnmarshaller:
                     # FIXME: ugly trick
                     field_type = JavaString(field_type.name)
 
-                if type(field_type) is not JavaString:
+                if type(field_type) is not JavaString:  # pylint:disable=C0123
                     raise AssertionError(
                         "Field type must be a JavaString, "
                         "not {0}".format(type(field_type))
@@ -367,8 +373,8 @@ class JavaObjectUnmarshaller:
             clazz.fields_types.append(field_type)
 
         if parent:
-            parent.__fields = clazz.fields_names
-            parent.__types = clazz.fields_types
+            parent.__fields = clazz.fields_names  # pylint:disable=W0212
+            parent.__types = clazz.fields_types  # pylint:disable=W0212
 
         # classAnnotation
         (opid,) = self._readStruct(">B")
@@ -656,7 +662,9 @@ class JavaObjectUnmarshaller:
             array = JavaByteArray(self.object_stream.read(size), classdesc)
         elif self.use_numpy_arrays and numpy is not None:
             array = numpy.fromfile(
-                self.object_stream, dtype=NUMPY_TYPE_MAP[type_code], count=size,
+                self.object_stream,
+                dtype=NUMPY_TYPE_MAP[type_code],
+                count=size,
             )
         else:
             for _ in range(size):
@@ -712,7 +720,10 @@ class JavaObjectUnmarshaller:
         )
         enum.classdesc = classdesc
         self._add_reference(enum, ident)
-        _, enumConstantName = self._read_and_exec_opcode(
+        (
+            _,
+            enumConstantName,
+        ) = self._read_and_exec_opcode(  # pylint:disable=C0103
             ident=ident + 1,
             expect=(TerminalCode.TC_STRING, TerminalCode.TC_REFERENCE),
         )
@@ -823,7 +834,8 @@ class JavaObjectUnmarshaller:
         log_error("==Oops state dump" + "=" * (30 - 17))
         log_error("References: {0}".format(self.references))
         log_error(
-            "Stream seeking back at -16 byte (2nd line is an actual position!):"
+            "Stream seeking back at -16 byte "
+            "(2nd line is an actual position!):"
         )
 
         # Do not use a keyword argument
