@@ -5,12 +5,12 @@ See: https://github.com/frohoff/jdeserialize
 
 :authors: Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.1
+:version: 0.4.3
 :status: Alpha
 
 ..
 
-    Copyright 2020 Thomas Calmant
+    Copyright 2021 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -27,13 +27,18 @@ See: https://github.com/frohoff/jdeserialize
 
 from __future__ import absolute_import
 
-from enum import Enum
-from typing import Any, Callable, Dict, IO, List, Optional
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    IO,
+    List,
+    Optional,
+)  # pylint:disable=W0611
 import logging
 import os
-import struct
 
-from . import api
+from . import api  # pylint:disable=W0611
 from .beans import (
     ParsedJavaContent,
     BlockData,
@@ -53,19 +58,20 @@ from .beans import (
 from .stream import DataStreamReader
 from .transformers import DefaultObjectTransformer
 from ..constants import (
-    ClassDescFlags,
     StreamConstants,
     TerminalCode,
     TypeCode,
     PRIMITIVE_TYPES,
 )
 
-from ..modifiedutf8 import decode_modified_utf8
+from ..modifiedutf8 import (
+    decode_modified_utf8,
+)  # pylint:disable=W0611  # noqa: F401
 
 # ------------------------------------------------------------------------------
 
 # Module version
-__version_info__ = (0, 4, 1)
+__version_info__ = (0, 4, 3)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -200,7 +206,8 @@ class JavaStreamParser:
         lines.append("")
         return "\n".join(lines)
 
-    def _dump_instance(self, instance):
+    @staticmethod
+    def _dump_instance(instance):
         # type: (JavaInstance) -> List[str]
         """
         Dumps an instance to a set of lines
@@ -233,7 +240,7 @@ class JavaStreamParser:
                     else:
                         line += "r0x{0:x}".format(h)
 
-                    line += ": " + str(c)
+                    line += ": " + str(content)
                 else:
                     line += str(obj)
 
@@ -273,7 +280,8 @@ class JavaStreamParser:
 
         self.__handles[handle] = content
 
-    def _do_null(self, _):
+    @staticmethod
+    def _do_null(_):
         """
         The easiest one
         """
@@ -335,7 +343,8 @@ class JavaStreamParser:
             length = self.__reader.read_long()
             if length < 0 or length > 2147483647:
                 raise ValueError("Invalid string length: {0}".format(length))
-            elif length < 65536:
+
+            if length < 65536:
                 self._log.warning("Small string stored as a long one")
 
         # Parse the content
@@ -412,7 +421,9 @@ class JavaStreamParser:
             # Reference to an already loading class description
             previous = self._do_reference()
             if not isinstance(previous, JavaClassDesc):
-                raise ValueError("Referenced object is not a class description")
+                raise ValueError(
+                    "Referenced object is not a class description"
+                )
             return previous
         elif type_code == TerminalCode.TC_PROXYCLASSDESC:
             # Proxy class description
@@ -597,26 +608,29 @@ class JavaStreamParser:
         """
         if field_type == FieldType.BYTE:
             return self.__reader.read_byte()
-        elif field_type == FieldType.CHAR:
+        if field_type == FieldType.CHAR:
             return self.__reader.read_char()
-        elif field_type == FieldType.DOUBLE:
+        if field_type == FieldType.DOUBLE:
             return self.__reader.read_double()
-        elif field_type == FieldType.FLOAT:
+        if field_type == FieldType.FLOAT:
             return self.__reader.read_float()
-        elif field_type == FieldType.INTEGER:
+        if field_type == FieldType.INTEGER:
             return self.__reader.read_int()
-        elif field_type == FieldType.LONG:
+        if field_type == FieldType.LONG:
             return self.__reader.read_long()
-        elif field_type == FieldType.SHORT:
+        if field_type == FieldType.SHORT:
             return self.__reader.read_short()
-        elif field_type == FieldType.BOOLEAN:
+        if field_type == FieldType.BOOLEAN:
             return self.__reader.read_bool()
-        elif field_type in (FieldType.OBJECT, FieldType.ARRAY):
+        if field_type in (FieldType.OBJECT, FieldType.ARRAY):
             sub_type_code = self.__reader.read_byte()
             if field_type == FieldType.ARRAY:
+                if sub_type_code == TerminalCode.TC_NULL:
+                    # Seems required, according to issue #46
+                    return None
                 if sub_type_code == TerminalCode.TC_REFERENCE:
                     return self._do_classdesc(sub_type_code)
-                elif sub_type_code != TerminalCode.TC_ARRAY:
+                if sub_type_code != TerminalCode.TC_ARRAY:
                     raise ValueError(
                         "Array type listed, but type code != TC_ARRAY"
                     )
