@@ -8,12 +8,12 @@ http://download.oracle.com/javase/6/docs/platform/serialization/spec/protocol.ht
 
 :authors: Volodymyr Buell, Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.1
+:version: 0.4.3
 :status: Alpha
 
 ..
 
-    Copyright 2020 Thomas Calmant
+    Copyright 2021 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -32,8 +32,6 @@ http://download.oracle.com/javase/6/docs/platform/serialization/spec/protocol.ht
 from __future__ import print_function
 
 # Standard library
-from javaobj.utils import bytes_char
-import javaobj.v2 as javaobj
 import logging
 import os
 import subprocess
@@ -47,6 +45,8 @@ from io import BytesIO
 sys.path.insert(0, os.path.abspath(os.path.dirname(os.getcwd())))
 
 # Local
+from javaobj.utils import bytes_char, java_data_fd
+import javaobj.v2 as javaobj
 
 # ------------------------------------------------------------------------------
 
@@ -247,6 +247,36 @@ class TestJavaobjV2(unittest.TestCase):
         pobj = javaobj.loads(jobj)
         _logger.debug("Read char objects: %s", pobj)
         self.assertEqual(pobj, expected)
+        self.assertEqual(pobj, expected.decode("latin1"))
+
+    def test_gzip_open(self):
+        """
+        Tests if the GZip auto-uncompress works
+        """
+        with java_data_fd(self.read_file("testChars.ser", stream=True)) as fd:
+            base = fd.read()
+
+        with java_data_fd(
+            self.read_file("testChars.ser.gz", stream=True)
+        ) as fd:
+            gzipped = fd.read()
+
+        self.assertEqual(
+            base, gzipped, "Uncompressed content doesn't match the original"
+        )
+
+    def test_chars_gzip(self):
+        """
+        Reads testChars.ser.gz
+        """
+        # Expected string as a UTF-16 string
+        expected = "python-javaobj".encode("utf-16-be")
+
+        jobj = self.read_file("testChars.ser.gz")
+        pobj = javaobj.loads(jobj)
+        _logger.debug("Read char objects: %s", pobj)
+        self.assertEqual(pobj, expected)
+        self.assertEqual(pobj, expected.decode("latin1"))
 
     def test_double_rw(self):
         """
